@@ -1,4 +1,3 @@
-from __future__ import print_function
 import re
 import sqlparse
 from sqlparse.sql import IdentifierList, Identifier, Function
@@ -203,10 +202,28 @@ def queries_start_with(queries, prefixes):
     return False
 
 
+def query_has_where_clause(query):
+    """Check if the query contains a where-clause."""
+    return any(
+        isinstance(token, sqlparse.sql.Where)
+        for token_list in sqlparse.parse(query)
+        for token in token_list
+    )
+
+
 def is_destructive(queries):
     """Returns if any of the queries in *queries* is destructive."""
     keywords = ('drop', 'shutdown', 'delete', 'truncate', 'alter')
-    return queries_start_with(queries, keywords)
+    for query in sqlparse.split(queries):
+        if query:
+            if query_starts_with(query, keywords) is True:
+                return True
+            elif query_starts_with(
+                query, ['update']
+            ) is True and not query_has_where_clause(query):
+                return True
+
+    return False
 
 
 def is_open_quote(sql):
@@ -220,3 +237,32 @@ def is_open_quote(sql):
 if __name__ == '__main__':
     sql = 'select * from (select t. from tabl t'
     print (extract_tables(sql))
+
+
+def is_dropping_database(queries, dbname):
+    """Determine if the query is dropping a specific database."""
+    if dbname is None:
+        return False
+
+    def normalize_db_name(db):
+        return db.lower().strip('`"')
+
+    dbname = normalize_db_name(dbname)
+
+    for query in sqlparse.parse(queries):
+        keywords = [t for t in query.tokens if t.is_keyword]
+        if len(keywords) < 2:
+            continue
+        if keywords[0].normalized == "DROP" and keywords[1].value.lower() in (
+            "database",
+            "schema",
+        ):
+            database_token = next(
+                (t for t in query.tokens if isinstance(t, Identifier)), None
+            )
+            return (
+                database_token is not None
+                and normalize_db_name(database_token.get_name()) == dbname
+            )
+    else:
+        return False
