@@ -1,5 +1,3 @@
-# -*- coding: utf-8
-from __future__ import unicode_literals
 from textwrap import dedent
 
 from behave import then, when
